@@ -1,5 +1,5 @@
 package GitLab::API::v4::Constants;
-$GitLab::API::v4::Constants::VERSION = '0.11';
+$GitLab::API::v4::Constants::VERSION = '0.12';
 =encoding utf8
 
 =head1 NAME
@@ -10,7 +10,7 @@ GitLab::API::v4::Constants - GitLab API v4 constants.
 
     use GitLab::API::v4::Constants qw( :all );
     
-    print $GITLAB_INTERNAL_VISIBILITY_LEVEL; # 10
+    print $GITLAB_ACCESS_LEVEL_GUEST; # 10
 
 =cut
 
@@ -98,6 +98,49 @@ const our @GITLAB_ACCESS_LEVELS => (
 );
 push @EXPORT_OK, '@GITLAB_ACCESS_LEVELS';
 
+=head2 $GITLAB_SNIPPET_VISIBILITY_LEVEL_PRIVATE
+
+C<private>
+
+=cut
+
+const our $GITLAB_SNIPPET_VISIBILITY_LEVEL_PRIVATE => 'private';
+push @EXPORT_OK, '$GITLAB_SNIPPET_VISIBILITY_LEVEL_PRIVATE';
+
+=head2 $GITLAB_SNIPPET_VISIBILITY_LEVEL_INTERNAL
+
+C<internal>
+
+=cut
+
+const our $GITLAB_SNIPPET_VISIBILITY_LEVEL_INTERNAL => 'internal';
+push @EXPORT_OK, '$GITLAB_SNIPPET_VISIBILITY_LEVEL_INTERNAL';
+
+=head2 $GITLAB_SNIPPET_VISIBILITY_LEVEL_PUBLIC
+
+C<public>
+
+=cut
+
+const our $GITLAB_SNIPPET_VISIBILITY_LEVEL_PUBLIC => 'public';
+push @EXPORT_OK, '$GITLAB_SNIPPET_VISIBILITY_LEVEL_PUBLIC';
+
+=head2 @GITLAB_SNIPPET_VISIBILITY_LEVELS
+
+An array containing the values for
+L</$GITLAB_SNIPPET_VISIBILITY_LEVEL_PRIVATE>,
+L</$GITLAB_SNIPPET_VISIBILITY_LEVEL_INTERNAL>, and
+L</$GITLAB_SNIPPET_VISIBILITY_LEVEL_PUBLIC>.
+
+=cut
+
+const our @GITLAB_SNIPPET_VISIBILITY_LEVELS => (
+    $GITLAB_SNIPPET_VISIBILITY_LEVEL_PRIVATE,
+    $GITLAB_SNIPPET_VISIBILITY_LEVEL_INTERNAL,
+    $GITLAB_SNIPPET_VISIBILITY_LEVEL_PUBLIC,
+);
+push @EXPORT_OK, '@GITLAB_SNIPPET_VISIBILITY_LEVELS';
+
 1;
 __END__
 
